@@ -930,7 +930,7 @@ See L<https://github.com/mche/Mojolicious-Plugin-RoutesAuthDBI/blob/master/Diagr
 
     $app->plugin('RoutesAuthDBI', 
         ...
-        admin => {< options below >},
+        admin => {< hashref options list below >},
         ...
     );
 
@@ -959,6 +959,10 @@ String. Is a url subprefix for trust admin urls of this module. See defaults bel
 
 String. Is a name of role for admonistrators.
 
+=head3 tables
+
+Hashref of any DB tables names. See L<Mojolicious::Plugin::RoutesAuthDBI::Schema#Default-variables-for-SQL-templates>.
+
 =head2 Default options
 
   admin = > {
