@@ -1,9 +1,10 @@
 package Mojolicious::Plugin::RoutesAuthDBI::Model::Routes;
-use Mojo::Base 'DBIx::Mojo::Model';
+#~ use Mojo::Base 'DBIx::Mojo::Model';
+use Mojo::Base 'Mojolicious::Plugin::RoutesAuthDBI::Model::Base';
 
-sub new {
-  state $self = shift->SUPER::new(@_);
-}
+#~ sub new {
+  #~ state $self = shift->SUPER::new(@_);
+#~ }
 
 sub routes {
   my $self = ref($_[0]) ? shift : shift->new;
@@ -44,7 +45,12 @@ where r.id2=?;
 
 @@ apply routes
 --- Генерация маршрутов приложения
-select r.*, coalesce(ac.controller, c.controller) as controller, coalesce(r.namespace, coalesce(ac.namespace, c.namespace)) as namespace, ac.action, ac.callback, ac.id as action_id, coalesce(ac.controller_id, c.id) as controller_id, case when r.namespace is not null then null else coalesce(ac.namespace_id, c.namespace_id) end as namespace_id
+select r.*,
+  coalesce(ac.controller, c.controller) as controller,
+  coalesce(r.namespace, coalesce(ac.namespace, c.namespace)) as namespace,
+  ac.action, ac.callback, ac.id as action_id,
+  coalesce(ac.controller_id, c.id) as controller_id,
+  case when r.namespace is not null then null else coalesce(ac.namespace_id, c.namespace_id) end as namespace_id
 from "{%= $schema %}"."{%= $tables->{routes} %}" r
 ---  join "{%= $schema %}"."{%= $tables->{refs} %}" rf on r.id=rf.id2
 
